=======
etlstat
=======

**etlstat** is a Python package that contains **Extract-Transform-Load**
utilities for statistical offices data processing.

It's been created by the Instituto Cántabro de Estadística (ICANE) and
belongs to ICANE's Python data framework.

